# coding: utf-8

# flake8: noqa

"""
    Kleister OpenAPI

    API definition for Kleister, manage mod packs for Minecraft

    The version of the OpenAPI document: 1.0.0-alpha1
    Contact: kleister@webhippie.de
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.0.2"

# Define package exports
__all__ = [
    "AuthApi",
    "FabricApi",
    "ForgeApi",
    "GroupApi",
    "MinecraftApi",
    "ModApi",
    "NeoforgeApi",
    "PackApi",
    "ProfileApi",
    "QuiltApi",
    "UserApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AttachBuildToVersionRequest",
    "AttachMinecraftToBuildRequest",
    "AuthToken",
    "AuthVerify",
    "Build",
    "BuildVersion",
    "CreateBuildRequest",
    "CreateGroupRequest",
    "CreateModRequest",
    "CreatePackRequest",
    "CreateUserRequest",
    "CreateVersionRequest",
    "DeleteGroupFromModRequest",
    "DeleteGroupFromPackRequest",
    "DeletePackFromGroupRequest",
    "DeletePackFromUserRequest",
    "Fabric",
    "Forge",
    "Group",
    "GroupMod",
    "GroupPack",
    "ListBuildVersions200Response",
    "ListBuilds200Response",
    "ListFabricBuilds200Response",
    "ListFabrics200Response",
    "ListForgeBuilds200Response",
    "ListForges200Response",
    "ListGroupMods200Response",
    "ListGroupPacks200Response",
    "ListGroupUsers200Response",
    "ListGroups200Response",
    "ListMinecraftBuilds200Response",
    "ListMinecrafts200Response",
    "ListModGroups200Response",
    "ListModUsers200Response",
    "ListMods200Response",
    "ListNeoforgeBuilds200Response",
    "ListNeoforges200Response",
    "ListPackGroups200Response",
    "ListPackUsers200Response",
    "ListPacks200Response",
    "ListProviders200Response",
    "ListQuiltBuilds200Response",
    "ListQuilts200Response",
    "ListUserGroups200Response",
    "ListUserMods200Response",
    "ListUserPacks200Response",
    "ListUsers200Response",
    "ListVersionBuilds200Response",
    "ListVersions200Response",
    "LoginAuthRequest",
    "Minecraft",
    "Mod",
    "ModAvatar",
    "Neoforge",
    "Notification",
    "Pack",
    "PackAvatar",
    "PermitGroupModRequest",
    "PermitGroupPackRequest",
    "PermitPackGroupRequest",
    "PermitPackUserRequest",
    "Profile",
    "Provider",
    "Quilt",
    "RedirectAuthRequest",
    "UpdateProfileRequest",
    "UpdateUserRequest",
    "User",
    "UserAuth",
    "UserGroup",
    "UserMod",
    "UserPack",
    "Validation",
    "Version",
    "VersionFile",
]

# import apis into sdk package
from kleister.api.auth_api import AuthApi as AuthApi
from kleister.api.fabric_api import FabricApi as FabricApi
from kleister.api.forge_api import ForgeApi as ForgeApi
from kleister.api.group_api import GroupApi as GroupApi
from kleister.api.minecraft_api import MinecraftApi as MinecraftApi
from kleister.api.mod_api import ModApi as ModApi
from kleister.api.neoforge_api import NeoforgeApi as NeoforgeApi
from kleister.api.pack_api import PackApi as PackApi
from kleister.api.profile_api import ProfileApi as ProfileApi
from kleister.api.quilt_api import QuiltApi as QuiltApi
from kleister.api.user_api import UserApi as UserApi

# import ApiClient
from kleister.api_response import ApiResponse as ApiResponse
from kleister.api_client import ApiClient as ApiClient
from kleister.configuration import Configuration as Configuration
from kleister.exceptions import OpenApiException as OpenApiException
from kleister.exceptions import ApiTypeError as ApiTypeError
from kleister.exceptions import ApiValueError as ApiValueError
from kleister.exceptions import ApiKeyError as ApiKeyError
from kleister.exceptions import ApiAttributeError as ApiAttributeError
from kleister.exceptions import ApiException as ApiException

# import models into sdk package
from kleister.models.attach_build_to_version_request import AttachBuildToVersionRequest as AttachBuildToVersionRequest
from kleister.models.attach_minecraft_to_build_request import AttachMinecraftToBuildRequest as AttachMinecraftToBuildRequest
from kleister.models.auth_token import AuthToken as AuthToken
from kleister.models.auth_verify import AuthVerify as AuthVerify
from kleister.models.build import Build as Build
from kleister.models.build_version import BuildVersion as BuildVersion
from kleister.models.create_build_request import CreateBuildRequest as CreateBuildRequest
from kleister.models.create_group_request import CreateGroupRequest as CreateGroupRequest
from kleister.models.create_mod_request import CreateModRequest as CreateModRequest
from kleister.models.create_pack_request import CreatePackRequest as CreatePackRequest
from kleister.models.create_user_request import CreateUserRequest as CreateUserRequest
from kleister.models.create_version_request import CreateVersionRequest as CreateVersionRequest
from kleister.models.delete_group_from_mod_request import DeleteGroupFromModRequest as DeleteGroupFromModRequest
from kleister.models.delete_group_from_pack_request import DeleteGroupFromPackRequest as DeleteGroupFromPackRequest
from kleister.models.delete_pack_from_group_request import DeletePackFromGroupRequest as DeletePackFromGroupRequest
from kleister.models.delete_pack_from_user_request import DeletePackFromUserRequest as DeletePackFromUserRequest
from kleister.models.fabric import Fabric as Fabric
from kleister.models.forge import Forge as Forge
from kleister.models.group import Group as Group
from kleister.models.group_mod import GroupMod as GroupMod
from kleister.models.group_pack import GroupPack as GroupPack
from kleister.models.list_build_versions200_response import ListBuildVersions200Response as ListBuildVersions200Response
from kleister.models.list_builds200_response import ListBuilds200Response as ListBuilds200Response
from kleister.models.list_fabric_builds200_response import ListFabricBuilds200Response as ListFabricBuilds200Response
from kleister.models.list_fabrics200_response import ListFabrics200Response as ListFabrics200Response
from kleister.models.list_forge_builds200_response import ListForgeBuilds200Response as ListForgeBuilds200Response
from kleister.models.list_forges200_response import ListForges200Response as ListForges200Response
from kleister.models.list_group_mods200_response import ListGroupMods200Response as ListGroupMods200Response
from kleister.models.list_group_packs200_response import ListGroupPacks200Response as ListGroupPacks200Response
from kleister.models.list_group_users200_response import ListGroupUsers200Response as ListGroupUsers200Response
from kleister.models.list_groups200_response import ListGroups200Response as ListGroups200Response
from kleister.models.list_minecraft_builds200_response import ListMinecraftBuilds200Response as ListMinecraftBuilds200Response
from kleister.models.list_minecrafts200_response import ListMinecrafts200Response as ListMinecrafts200Response
from kleister.models.list_mod_groups200_response import ListModGroups200Response as ListModGroups200Response
from kleister.models.list_mod_users200_response import ListModUsers200Response as ListModUsers200Response
from kleister.models.list_mods200_response import ListMods200Response as ListMods200Response
from kleister.models.list_neoforge_builds200_response import ListNeoforgeBuilds200Response as ListNeoforgeBuilds200Response
from kleister.models.list_neoforges200_response import ListNeoforges200Response as ListNeoforges200Response
from kleister.models.list_pack_groups200_response import ListPackGroups200Response as ListPackGroups200Response
from kleister.models.list_pack_users200_response import ListPackUsers200Response as ListPackUsers200Response
from kleister.models.list_packs200_response import ListPacks200Response as ListPacks200Response
from kleister.models.list_providers200_response import ListProviders200Response as ListProviders200Response
from kleister.models.list_quilt_builds200_response import ListQuiltBuilds200Response as ListQuiltBuilds200Response
from kleister.models.list_quilts200_response import ListQuilts200Response as ListQuilts200Response
from kleister.models.list_user_groups200_response import ListUserGroups200Response as ListUserGroups200Response
from kleister.models.list_user_mods200_response import ListUserMods200Response as ListUserMods200Response
from kleister.models.list_user_packs200_response import ListUserPacks200Response as ListUserPacks200Response
from kleister.models.list_users200_response import ListUsers200Response as ListUsers200Response
from kleister.models.list_version_builds200_response import ListVersionBuilds200Response as ListVersionBuilds200Response
from kleister.models.list_versions200_response import ListVersions200Response as ListVersions200Response
from kleister.models.login_auth_request import LoginAuthRequest as LoginAuthRequest
from kleister.models.minecraft import Minecraft as Minecraft
from kleister.models.mod import Mod as Mod
from kleister.models.mod_avatar import ModAvatar as ModAvatar
from kleister.models.neoforge import Neoforge as Neoforge
from kleister.models.notification import Notification as Notification
from kleister.models.pack import Pack as Pack
from kleister.models.pack_avatar import PackAvatar as PackAvatar
from kleister.models.permit_group_mod_request import PermitGroupModRequest as PermitGroupModRequest
from kleister.models.permit_group_pack_request import PermitGroupPackRequest as PermitGroupPackRequest
from kleister.models.permit_pack_group_request import PermitPackGroupRequest as PermitPackGroupRequest
from kleister.models.permit_pack_user_request import PermitPackUserRequest as PermitPackUserRequest
from kleister.models.profile import Profile as Profile
from kleister.models.provider import Provider as Provider
from kleister.models.quilt import Quilt as Quilt
from kleister.models.redirect_auth_request import RedirectAuthRequest as RedirectAuthRequest
from kleister.models.update_profile_request import UpdateProfileRequest as UpdateProfileRequest
from kleister.models.update_user_request import UpdateUserRequest as UpdateUserRequest
from kleister.models.user import User as User
from kleister.models.user_auth import UserAuth as UserAuth
from kleister.models.user_group import UserGroup as UserGroup
from kleister.models.user_mod import UserMod as UserMod
from kleister.models.user_pack import UserPack as UserPack
from kleister.models.validation import Validation as Validation
from kleister.models.version import Version as Version
from kleister.models.version_file import VersionFile as VersionFile

